@@ -8,7 +8,7 @@
  *
  *****************************************************************************/
 
-// $Id: kupubasetools.js 21220 2005-12-16 15:47:11Z duncan $
+// $Id: kupubasetools.js 27123 2006-05-12 10:19:22Z duncan $
 
 
 //----------------------------------------------------------------------------
@@ -338,8 +338,8 @@ function KupuUI(textstyleselectid) {
         parastyles['p'] = 0;
         while (options.length > 1) {
             opt = options[1];
-            var v = opt.value;
-            if (/^thead|tbody|table|t[rdh]\b/i.test(v)) {
+            var v = opt.value.toLowerCase();
+            if (/^thead|tbody|table|t[rdh]\b/.test(v)) {
                 var otable = tableoptions;
                 var styles = tablestyles;
             } else {
@@ -2551,8 +2551,7 @@ KupuZoomTool.prototype.onresize = function() {
     }
     width = width + 'px';
     var offset = iframe.offsetTop;
-    if (sourceArea) offset = sourceArea.offsetTop-1;
-    // XXX: TODO: Using wrong values here, figure out why.
+    if (sourceArea && sourceArea.offsetTop) offset = sourceArea.offsetTop-1;
     var nheight = Math.max(height - offset -1/*top border*/, 10);
     nheight = nheight + 'px';
     fulleditor.style.width = width; /*IE needs this*/
@@ -2560,7 +2559,7 @@ KupuZoomTool.prototype.onresize = function() {
     iframe.style.height = nheight;
     if (sourceArea) {
         sourceArea.style.width = width;
-        sourceArea.style.height = height;
+        sourceArea.style.height = nheight;
     }
 }
 
